@@ -29,7 +29,6 @@ INCLUDEFILE="include_if"
 BROKENUPPREPAREFILE="broken_up_prepare"
 BROKENUPPREPAREFILE2="broken_up_prepare2"
 BROKENUPPREPAREFILE3="broken_up_prepare3"
-BROKENUPPREPAREFILE4="broken_up_prepare4"
 BROKENUPFILE="broken_up"
 BROKENUPFILE2="broken_up2"
 NEWFILE="prepare"
@@ -53,43 +52,42 @@ BREAK_TE(){
 			echo "Cannot find file $SOURCEFILE" 1>&2
 			ERROR=1
 		else
-			#echo ""
-			#echo ""
-			#echo "SOURCEFILE:"$SOURCEFILE
-	########### write include(`all.if') first line of the source file#######################################
-			cat $INCLUDEIFFILE $SOURCEFILE > $INCLUDEFILE
-			m4 $INCLUDEFILE > $BROKENUPPREPAREFILE
-			####interface to define
-			sed 's/interface/define/g' $BROKENUPPREPAREFILE > $BROKENUPPREPAREFILE2
-			####make preparaton
-			m4 $BROKENUPPREPAREFILE2 > $BROKENUPPREPAREFILE3
-	########### write include(`all.spt') first line of the brokenupprepare file number#######################################
-			cat $INCLUDESPTFILE $BROKENUPPREPAREFILE3 > $BROKENUPPREPAREFILE4
-			####put this to first line
-			m4 $BROKENUPPREPAREFILE4 > $BROKENUPFILE
-			####this is done
-			#echo "Success making "$BROKENUPFILE
-			#echo "NOW MAKING RAWFILE PLEASE WAIT!"
-	########### make broken .te_raw#######################################
-			sed 's/# Declarations/Declarations/g' $BROKENUPFILE > $BROKENUPFILE2
-			COMP_STR="Declarations"
-			csplit $BROKENUPFILE2 /^$COMP_STR/ {*}
-			sed 's/Declarations/# Declarations/g' xx01 > $NEWFILE
-	########### eliminate blank lines#######################################
-			NEWFILE_NEW=$SOURCEFILE"_raw"
-			grep [a-zA-Z#{}] "$NEWFILE" > "$NEWFILE_NEW"
-			echo "Made "$NEWFILE_NEW
+
+        ########### write include(`all.if') first line of the source file#######################################
+#######################################edited on 7.870####################################################
+			cp ../all.if all.if_now_pre
+                        ####interface to define
+                        sed 's/interface/define/g' all.if_now_pre > all.if_now
+                        cat all.if_now $SOURCEFILE > $INCLUDEFILE
+                        m4 $INCLUDEFILE > $BROKENUPPREPAREFILE
+                        ####make preparaton
+                        m4 $BROKENUPPREPAREFILE > $BROKENUPPREPAREFILE2
+        ########### write include(`all.spt') first line of the brokenupprepare file number#######################################
+                        cat $INCLUDESPTFILE $BROKENUPPREPAREFILE2 > $BROKENUPPREPAREFILE3
+                        ####put this to first line
+                        m4 $BROKENUPPREPAREFILE3 > $BROKENUPFILE
+        ########### make broken .te_raw#######################################
+                        sed 's/# Declarations/Declarations/g' $BROKENUPFILE > $BROKENUPFILE2
+                        COMP_STR="Declarations"
+                        csplit $BROKENUPFILE2 /^$COMP_STR/ {*}
+                        sed 's/Declarations/# Declarations/g' xx01 > $NEWFILE
+        ########### eliminate blank lines#######################################
+                        NEWFILE_NEW=$SOURCEFILE"_raw"
+                        grep [a-zA-Z#{}] "$NEWFILE" > "$NEWFILE_NEW"
+
 		fi
 
 		unlink $BROKENUPPREPAREFILE
 		unlink $BROKENUPPREPAREFILE2
 		unlink $BROKENUPPREPAREFILE3
-		unlink $BROKENUPPREPAREFILE4
 		unlink $BROKENUPFILE
 		unlink $BROKENUPFILE2
 		unlink $NEWFILE
 		unlink $CSPLITFILE
 		unlink $CSPLITFILE2
+		unlink all.if_now
+		unlink all.if_now_pre
+		unlink $INCLUDEFILE
 
 	done < "$FILELIST"
 
