@@ -61,16 +61,16 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 
         fedoraVersionButtonGroup = new Q3ButtonGroup(this);
         fedoraVersionButtonGroup->resize( 150, 70 );
-        fifteenRadioButton = new QRadioButton(tr("version 15"), fedoraVersionButtonGroup);
-        fifteenRadioButton->setGeometry( 10, 10, 300, 20 );
-        sixteenRadioButton = new QRadioButton(tr("version 16"), fedoraVersionButtonGroup);
-        sixteenRadioButton->setGeometry( 10, 30, 300, 20 );
-        seventeenRadioButton = new QRadioButton(tr("version 17"), fedoraVersionButtonGroup);
-        seventeenRadioButton->setGeometry( 10, 50, 300, 20 );
-        eighteenRadioButton = new QRadioButton(tr("version 18"), fedoraVersionButtonGroup);
-        eighteenRadioButton->setGeometry( 10, 70, 300, 20 );
+        new4RadioButton = new QRadioButton(tr("version 15"), fedoraVersionButtonGroup);
+        new4RadioButton->setGeometry( 10, 10, 300, 20 );
+        new3RadioButton = new QRadioButton(tr("version 16"), fedoraVersionButtonGroup);
+        new3RadioButton->setGeometry( 10, 30, 300, 20 );
+        new2RadioButton = new QRadioButton(tr("version 17"), fedoraVersionButtonGroup);
+        new2RadioButton->setGeometry( 10, 50, 300, 20 );
+        newRadioButton = new QRadioButton(tr("version 18"), fedoraVersionButtonGroup);
+        newRadioButton->setGeometry( 10, 70, 300, 20 );
 
-	eighteenRadioButton->setChecked(true);
+	newRadioButton->setChecked(true);
 
 	downloadButton = new QPushButton(tr("Download Fedora"), this);
 	downloadButton->setPaletteBackgroundColor(QColor(100,200,200));
@@ -91,10 +91,8 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	secondLayout = new Q3VBoxLayout;
 	thirdLayout = new Q3VBoxLayout;
 
-	//leftLayout = new QVBoxLayout;
 	rightLayout = new Q3HBoxLayout;
 	
-	//leftLayout->addWidget(optionButtonGroup);
 	secondLayout->addWidget(optionButtonGroup);
 	thirdLayout->addWidget(fedoraVersionButtonGroup);
 	firstLayout->addLayout(secondLayout);
@@ -103,7 +101,6 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	rightLayout->addWidget(downloadButton);
 	rightLayout->addStretch();
 
-	//middleLayout->addLayout(leftLayout);
 	middleLayout->addLayout(firstLayout);
 	middleLayout->addLayout(rightLayout);
 
@@ -113,97 +110,96 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	footLayout->addWidget(closeButton);
 
 	mainLayout->addLayout(middleLayout);
-	//mainLayout->addLayout(firstLayout);
 	mainLayout->addLayout(footLayout);
 	resize(660,250);
 }
 
 void Downloader::download_button_clicked()
 {
-	Q3Url url_for_fedora("ftp://mirrors.usc.edu");
+	Q3Url url_for_fedora("ftp://mirrors.kernel.org");
 	if(usRadioButton->isChecked()){
-		Q3Url url_for_fedora("ftp://mirrors.usc.edu");
+		Q3Url url_for_fedora("ftp://mirrors.kernel.org");
 		url_for_fedora.setPort(21);
 		mirror = 1;
-		if(fifteenRadioButton->isChecked()){
-			version = "fifteen";
+		if(new4RadioButton->isChecked()){
+			version = "new4";
 		}
-		if(sixteenRadioButton->isChecked()){
-			version = "sixteen";
+		if(new3RadioButton->isChecked()){
+			version = "new3";
 		}
-		if(seventeenRadioButton->isChecked()){
-			version = "seventeen";
+		if(new2RadioButton->isChecked()){
+			version = "new2";
 		}
-		if(eighteenRadioButton->isChecked()){
-			version = "eighteen";
+		if(newRadioButton->isChecked()){
+			version = "new";
 		}
 	}
 	if(jpRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.riken.jp");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fifteenRadioButton->isChecked()){
-			version = "fifteen";
+		if(new4RadioButton->isChecked()){
+			version = "new4";
 		}
-		if(sixteenRadioButton->isChecked()){
-			version = "sixteen";
+		if(new3RadioButton->isChecked()){
+			version = "new3";
 		}
-		if(seventeenRadioButton->isChecked()){
-			version = "seventeen";
+		if(new2RadioButton->isChecked()){
+			version = "new2";
 		}
-		if(eighteenRadioButton->isChecked()){
-			version = "eighteen";
+		if(newRadioButton->isChecked()){
+			version = "new";
 		}
 	}
 	if(deRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.uni-kl.de");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fifteenRadioButton->isChecked()){
-			version = "fifteen";
+		if(new4RadioButton->isChecked()){
+			version = "new4";
 		}
-		if(sixteenRadioButton->isChecked()){
-			version = "sixteen";
+		if(new3RadioButton->isChecked()){
+			version = "new3";
 		}
-		if(seventeenRadioButton->isChecked()){
-			version = "seventeen";
+		if(new2RadioButton->isChecked()){
+			version = "new2";
 		}
-		if(eighteenRadioButton->isChecked()){
-			version = "eighteen";
+		if(newRadioButton->isChecked()){
+			version = "new";
 		}
 	}
 	if(frRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.lip6.fr");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fifteenRadioButton->isChecked()){
-			version = "fifteen";
+		if(new4RadioButton->isChecked()){
+			version = "new4";
 		}
-		if(sixteenRadioButton->isChecked()){
-			version = "sixteen";
+		if(new3RadioButton->isChecked()){
+			version = "new3";
 		}
-		if(seventeenRadioButton->isChecked()){
-			version = "seventeen";
+		if(new2RadioButton->isChecked()){
+			version = "new2";
 		}
-		if(eighteenRadioButton->isChecked()){
-			version = "eighteen";
+		if(newRadioButton->isChecked()){
+			version = "new";
 		}
 	}
 	if(auRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://mirror.aarnet.edu.au");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		if(fifteenRadioButton->isChecked()){
-			version = "fifteen";
+		if(new4RadioButton->isChecked()){
+			version = "new4";
 		}
-		if(sixteenRadioButton->isChecked()){
-			version = "sixteen";
+		if(new3RadioButton->isChecked()){
+			version = "new3";
 		}
-		if(seventeenRadioButton->isChecked()){
-			version = "seventeen";
+		if(new2RadioButton->isChecked()){
+			version = "new2";
 		}
-		if(eighteenRadioButton->isChecked()){
-			version = "eighteen";
+		if(newRadioButton->isChecked()){
+			version = "new";
 		}
 	}
 	downloader_process(url_for_fedora,version);
@@ -221,31 +217,23 @@ void Downloader::downloader_process(const Q3Url &url_for_fedora, QString version
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
 	process->start();
 	QMessageBox::warning(0, tr("Downloader Fedora"),
-				tr("Downloading Fedora in /var/tmp directory."));
+				tr("Downloading Fedora in your home directory."));
 }
 void Downloader::updateOutputTextEdit()
 {
 	QByteArray data = process->readStderr();
-	//QString text = textEdit1->text() + QString(data);
-	//textEdit1->setText(text);
 }
 void Downloader::readFromStdout()
 {
 	QByteArray data = process->readStdout();
-	//QString text = textEdit1->text() + QString(data);
-	//textEdit1->setText(text);
 }
 void Downloader::processExited()
 {
 	if(process->normalExit()){
-		//textEdit1->append(tr("yum install process ended !"));
-		//textEdit1->append(tr("\n"));
 		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloaded files are in /var/tmp directory."));
+				     tr("Downloaded files in your home directory."));
 		return;
 	} else {
-		//textEdit1->append(tr("yum install process had an error !"));
-		//textEdit1->append(tr("\n"));
 		QMessageBox::warning(0, tr("Downloader Fedora"),
 				     tr("Downloader Fedora process had an error"));
 		return;
