@@ -110,6 +110,9 @@
 #include "segatex_booleannames.h"
 #include "segatex_getpidcon.h"
 #include "segatex_selinuxpath.h"
+#ifdef SEGATEX_VERSION
+#include "segatex_version.h"
+#endif
 //#include <iostream>
 //using namespace std;
 
@@ -174,7 +177,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-7.880"));
+	setWindowTitle(tr("segatex-7.900"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
@@ -575,12 +578,12 @@ void MainWindow::closeEvent(QCloseEvent *event)
  }
 void MainWindow::open()
 {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/usr/share/segatex",tr("Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv);;Any files(*)"));
+	QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/usr/share/segatex",tr("Any files(*);;Type Enforcement files(*.te);;File Context files(*.fc);;Interface files(*.if);;raw files(*raw);;policy module files(*.pp);;text files(*.txt);;csv files(*.csv)"));
 	if (!fileName.isEmpty()) {
 		QMdiSubWindow *existing = findMdiChild(fileName);
 		if (existing) {
 			mdiArea->setActiveSubWindow(existing);
-		return;
+			return;
 		}
 		MdiChild *child = createMdiChild();
 		if (child->loadFile(fileName)) {
@@ -625,7 +628,7 @@ void MainWindow::paste()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.880</h2>"
+		tr("<h2>segatex-7.900</h2>"
 		"<p>Copyright &copy; 2007-2013"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -756,16 +759,8 @@ MdiChild *MainWindow::createMdiChild()
 	}
 	else
 	{
-		//selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " " + getenforce_str + " is in use."
 		selinux_policy = "SELinux is " + enabled_or_not_str + " and "+ selinux_policy + " policy in " + getenforce_str + " mode. "
 		+ " Policy root is " + segatex_selinux_policy_root_str + " and version is " + segatex_security_policyvers_str + ".";
-		//+ " Policy root is " + segatex_selinux_policy_root_str;
-		/*
-		if(getenforce_str == "enforcing")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(155, 155, 255));
-		if(getenforce_str == "permissive")
-			segatexStateLabel->setPaletteBackgroundColor(QColor(255, 251, 126));
-		*/
 	}
 	return selinux_policy;
  }
@@ -779,11 +774,6 @@ MdiChild *MainWindow::createMdiChild()
 	segatexStateLabel = new QLabel(tr(selinux_policy), this);
 	segatexStateLabel->setAlignment(Qt::AlignHCenter);
 	segatex_security_policyvers_int = segatex_state->segatex_security_policyvers();
-/////////////////////test////////////////
-	//segatex_security_policyvers_const_char = (const char *)segatex_security_policyvers_int;	
-	//segatexStateLabel2 = new QLabel(tr(segatex_security_policyvers_const_char), this);
-	//segatexStateLabel2->setAlignment(Qt::AlignHCenter);
-/////////////////////end test////////////////
 
 	modLabel->setAlignment(Qt::AlignHCenter);
 	modLabel->setMinimumSize(modLabel->sizeHint());
@@ -823,7 +813,6 @@ MdiChild *MainWindow::createMdiChild()
      }
      return 0;
  }
-//this would be the one?
 void MainWindow::switchLayoutDirection()
 {
 	if (layoutDirection() == Qt::LeftToRight)
@@ -1199,11 +1188,8 @@ void MainWindow::enforcing()
 		segatex_apply = new SegatexApply(this);
 		connect(segatex_apply, SIGNAL(enforcingOn()), segatex_apply, SLOT(setenforce_enforcing())); 
 		connect(segatex_apply, SIGNAL(permissiveOn()), segatex_apply, SLOT(setenforce_permissive())); 
-//for test
 		connect(segatex_apply, SIGNAL(permissiveOn()), this, SLOT(updateSegatexStateIndicator()));
 		connect(segatex_apply, SIGNAL(enforcingOn()), this, SLOT(updateSegatexStateIndicator()));
-//end for test
-		//connect(segatex_apply, SIGNAL(disabledOn()), segatex_apply, SLOT(setenforce_disabled())); 
 		connect(previousAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 	}
 	segatex_apply->show();
